@@ -9,7 +9,4 @@ class Command(BaseCommand):
     help = "Updates Analytics most viewed data"
 
     def handle(self, *args, **options):
-        os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = os.path.join(
-            settings.SECRET_ROOT, "secrets/csgoogleanalytics_secrets.json"
-        )
         create_analytics()
