@@ -5,7 +5,6 @@ from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site
 from datetime import timedelta
 from django.contrib.sites.managers import CurrentSiteManager
-from .forms import CredentialsField
 
 
 class Analytics(models.Model):
@@ -29,55 +28,27 @@ class Analytics(models.Model):
         except:
             return None
 
-    def __unicode__(self):
+    def __str__(self):
         return self.title
 
+    class Meta:
+        verbose_name = "Bisiten analitika"
+        verbose_name_plural = "Bisiten analitikak"
+
 
 class AnalyticsProfile(models.Model):
     tracking_code = models.CharField(max_length=32, unique=True)
-    credentials = models.ForeignKey("CredentialsModel", on_delete=models.CASCADE)
     site = models.ForeignKey(Site, on_delete=models.CASCADE)
 
     objects = models.Manager()
     siteobjects = CurrentSiteManager()
 
+    def __str__(self):
+        return self.tracking_code
 
-class CredentialsModel(models.Model):
-    id = models.OneToOneField(
-        settings.AUTH_USER_MODEL, primary_key=True, on_delete=models.CASCADE
-    )
-    credential = CredentialsField()
-    site = models.ForeignKey(Site, on_delete=models.CASCADE)
-
-    objects = models.Manager()
-    siteobjects = CurrentSiteManager()
-
-    def is_valid(self):
-        try:
-            if self.credential.invalid:
-                return False
-            else:
-                return True
-        except:
-            return False
-
-    is_valid.boolean = True
-
-    def has_refresh_token(self):
-        if self.credential.refresh_token:
-            return True
-        else:
-            return False
-
-    has_refresh_token.boolean = True
-
-    def save(self, *args, **kwargs):
-        if not hasattr(self, "site") or self.site is None:
-            self.site = Site.objects.get(id=settings.SITE_ID)
-        super(CredentialsModel, self).save(*args, **kwargs)
-
-    def __unicode__(self):
-        return str(self.id.id)
+    class Meta:
+        verbose_name = "Analytics profila"
+        verbose_name_plural = "Analytics profilak"
 
 
 class AllowedPattern(models.Model):
@@ -100,12 +71,12 @@ PERIOD_CHOICES_FULL = {
     10: ("20y", timedelta(days=7300)),
 }
 
-PERIOD_CHOICES = [(key, value[0]) for key, value in PERIOD_CHOICES_FULL.items()]
+PERIOD_CHOICES = [
+    (key, value[0]) for key, value in PERIOD_CHOICES_FULL.items()
+]
 
 
 class Page(models.Model):
-    """ """
-
     pagepath = models.CharField(max_length=255)
     content_type = models.IntegerField()
     object_id = models.IntegerField()
@@ -136,17 +107,15 @@ class Page(models.Model):
         except:
             return None
 
-    def __unicode__(self):
+    def __str__(self):
         return self.pagepath
 
 
 class PageStats(models.Model):
-    """ """
-
     page = models.ForeignKey(Page, on_delete=models.CASCADE)
     period = models.SmallIntegerField(choices=PERIOD_CHOICES)
     pageviews = models.IntegerField(default=0)
     created_at = models.DateTimeField(auto_now_add=True)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.page.pagepath
