@@ -1,10 +1,27 @@
-import httplib2
-from googleapiclient.discovery import build
-from .models import CredentialsModel, AnalyticsProfile, Analytics, PageStats, Page
+import os
+from django.db.models import Max
+from google.analytics.data_v1beta import BetaAnalyticsDataClient
+from google.analytics.data_v1beta.types import (
+    DateRange,
+    Dimension,
+    Metric,
+    RunReportRequest,
+)
+
+from .models import (
+    AnalyticsProfile,
+    Analytics,
+    PageStats,
+    Page,
+)
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.paginator import Paginator
 
+SECRETS = os.path.join(
+    settings.SECRET_ROOT, "secrets/csgoogleanalytics_secrets.json"
+)
+
 URL_VALIDATOR = getattr(
     settings,
     "CSGOOGLEANALYTICS_URL_VALIDATOR",
@@ -19,43 +36,34 @@ def _load_validator():
     return validator
 
 
-def _build_analytics_service():
-    credentialsmodel = CredentialsModel.siteobjects.first()
-    credential = credentialsmodel.credential
-    # http = httplib2.Http()
-    # http = credential.authorize(http)
-    return build("analytics", "v3", credentials=credential)
-
-
-def get_most_viewed_urls(max_results=100):
-    service = _build_analytics_service()
+def get_most_viewed_urls():
+    client = BetaAnalyticsDataClient.from_service_account_file(SECRETS)
     profile = AnalyticsProfile.siteobjects.first()
-    return (
-        service.data()
-        .ga()
-        .get(
-            ids="ga:{}".format(profile.tracking_code),
-            start_date="yesterday",
-            end_date="today",
-            metrics="ga:pageviews",
-            dimensions="ga:pagePath",
-            sort="-ga:pageviews",
-            max_results=max_results,
-        )
-        .execute()
+
+    request = RunReportRequest(
+        property="properties/{}".format(profile.tracking_code),
+        dimensions=[Dimension(name="pagePath")],
+        metrics=[Metric(name="screenPageViews")],
+        date_ranges=[DateRange(start_date="yesterday", end_date="today")],
     )
+    return client.run_report(request)
 
 
-def create_analytics():
+def create_analytics(max_results=100):
     Analytics.siteobjects.all().delete()
     data = get_most_viewed_urls()
     validator = _load_validator()
-    for row in data.get("rows", []):
+    for row in data.rows[:max_results]:
         an = Analytics(
-            path=row[0], title=row[0], pageviews=row[1], site=Site.objects.get_current()
+            path=row.dimension_values[0].value,
+            title=row.dimension_values[0].value,
+            pageviews=row.metric_values[0].value,
+            site=Site.objects.get_current(),
         )
         try:
-            is_valid, title, photo_src, content_type, object_id = validator(row[0])
+            is_valid, title, photo_src, content_type, object_id = validator(
+                row.dimension_values[0].value
+            )
             an.is_valid = is_valid
             an.title = title
             an.photo_src = photo_src
@@ -96,7 +104,9 @@ def create_page_stats(pagepaths_list, start_date_str, end_date_str, period_id):
     pager = Paginator(pagepaths_list, 10)
     for i in pager.page_range:
         pagepaths = pager.page(i).object_list
-        results = get_pageviews_from_urls(pagepaths, start_date_str, end_date_str)
+        results = get_pageviews_from_urls(
+            pagepaths, start_date_str, end_date_str
+        )
         for row in results.get("rows", []):
             page = Page.objects.get(pagepath=row[0])
             PageStats.objects.filter(page=page, period=period_id).delete()
@@ -110,7 +120,9 @@ def create_page_stats(pagepaths_list, start_date_str, end_date_str, period_id):
 
 
 def page_stats_years():
-    return list(Page.objects.all().distinct().values_list("added_year", flat=True))
+    return list(
+        Page.objects.all().distinct().values_list("added_year", flat=True)
+    )
 
 
 def page_stats_months(year):
@@ -137,9 +149,6 @@ def page_stats_days(month):
     )
 
 
-from django.db.models import Max
-
-
 def page_year(year):
     qs = Page.objects.filter(added_year=year)
     qs = qs.annotate(bisitak=Max("pagestats__pageviews"))
